=====
heamy
=====

.. image:: https://img.shields.io/pypi/v/heamy.svg
        :target: https://pypi.python.org/pypi/heamy

.. image:: https://img.shields.io/travis/rushter/heamy.svg
        :target: https://travis-ci.org/rushter/heamy

.. image:: https://coveralls.io/repos/github/rushter/heamy/badge.svg?branch=master
        :target: https://coveralls.io/github/rushter/heamy?branch=master

A set of useful tools for competitive data science.


Installation
------------

To install Heamy, simply:

.. code:: bash

    $ pip install -U heamy


Features
--------
* Automatic caching (data preprocessing, predictions from models)
* Ensemble learning (stacking, blending, weighted average, etc.).


Documentation
-------------

* Documentation: http://heamy.readthedocs.io/en/latest/        
* Examples: https://github.com/rushter/heamy/tree/master/examples


